"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _graphql = require("gatsby/graphql");

var _commonFields = require("./commonFields");

var _cloudinary = require("./cloudinary");

var _default = function _default(_ref) {
  var pathPrefix = _ref.pathPrefix,
      getNodeAndSavePathDependency = _ref.getNodeAndSavePathDependency,
      reporter = _ref.reporter,
      cloudinary = _ref.cloudinary;
  return {
    type: new _graphql.GraphQLObjectType({
      name: 'ImageCloudinaryFixed',
      fields: (0, _objectSpread2.default)({}, (0, _commonFields.commonFields)({
        pathPrefix: pathPrefix,
        reporter: reporter,
        cloudinary: cloudinary
      }))
    }),
    args: {
      width: {
        type: _graphql.GraphQLInt,
        defaultValue: 400
      },
      height: {
        type: _graphql.GraphQLInt
      }
    },
    resolve: function () {
      var _resolve = (0, _asyncToGenerator2.default)(
      /*#__PURE__*/
      _regenerator.default.mark(function _callee(image, fieldArgs, context) {
        var file, id, path, data, presentationWidth, sizes;
        return _regenerator.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                /**
                 * This function has to provide the public_id
                 * of the uploaded image. Then other resolve functions
                 * will perform transformations on that public_id.
                 *
                 * This must also provide:
                 * - width
                 * - height
                 * - aspectRatio
                 * - sizes
                 *
                 * All the transformations will return remote urls on cloudinary.
                 */
                file = getNodeAndSavePathDependency(image.parent, context.path);
                id = file.id;
                path = file.absolutePath;
                _context.next = 5;
                return (0, _cloudinary.upload)(cloudinary)(id, path);

              case 5:
                data = _context.sent;
                presentationWidth = Math.min(fieldArgs.maxWidth, data.width);
                sizes = "(max-width: ".concat(presentationWidth, "px) 100vw, ").concat(presentationWidth, "px");
                return _context.abrupt("return", {
                  id: id,
                  path: path,
                  width: data.width,
                  height: data.height,
                  aspectRatio: data.width / data.height,
                  maxWidth: fieldArgs.maxWidth,
                  maxHeight: fieldArgs.maxHeight,
                  sizes: sizes
                });

              case 9:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      return function resolve(_x, _x2, _x3) {
        return _resolve.apply(this, arguments);
      };
    }()
  };
};

exports.default = _default;