"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.commonFields = void 0;

var _taggedTemplateLiteral2 = _interopRequireDefault(require("@babel/runtime/helpers/taggedTemplateLiteral"));

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _graphql = require("gatsby/graphql");

var _gatsbyPluginSharp = require("gatsby-plugin-sharp");

var _commonTags = require("common-tags");

var _sharpBase = require("sharp-base64");

function _templateObject2() {
  var data = (0, _taggedTemplateLiteral2.default)(["\n                A base64 version of the image or video. Can be used as a placeholder.\n            "]);

  _templateObject2 = function _templateObject2() {
    return data;
  };

  return data;
}

function _templateObject() {
  var data = (0, _taggedTemplateLiteral2.default)(["\n                The aspect ratio of the image (width/height).\n                Can be used to ensure there is space reserved for the image.\n                This can prevent page jank when the image loads.\n            "]);

  _templateObject = function _templateObject() {
    return data;
  };

  return data;
}

var getSrcDescription = function getSrcDescription(format) {
  return "Image src in ".concat(format, " format.");
};

var getSrcSetDescription = function getSrcSetDescription(format) {
  return "Image srcset in ".concat(format, " format.");
};

var commonFields = function commonFields(_ref) {
  var cloudinary = _ref.cloudinary;

  var getResolveSrc = function getResolveSrc(format) {
    return function (_ref2) {
      var id = _ref2.id;
      return cloudinary.url(id, {
        format: format,
        secure: true
      });
    };
  };

  var getResolveSrcSet = function getResolveSrcSet(format) {
    return (
      /*#__PURE__*/
      function () {
        var _ref4 = (0, _asyncToGenerator2.default)(
        /*#__PURE__*/
        _regenerator.default.mark(function _callee(_ref3) {
          var id, width, maxWidth, factors, widths, images, srcSet;
          return _regenerator.default.wrap(function _callee$(_context) {
            while (1) {
              switch (_context.prev = _context.next) {
                case 0:
                  id = _ref3.id, width = _ref3.width, maxWidth = _ref3.maxWidth;
                  factors = [0.25, 0.5, 1, 1.5, 2, 3]; // This is enough sizes to provide close to the optimal image size for every
                  // device size / screen resolution.
                  // We don't upscale the images.

                  widths = factors.map(function (x) {
                    return x * maxWidth;
                  }).map(function (x) {
                    return Math.round(x);
                  }).filter(function (x) {
                    return x < width;
                  }).concat(width).sort();
                  images = widths.map(function (width) {
                    return {
                      url: cloudinary.url(id, {
                        format: format,
                        width: width,
                        crop: 'fit',
                        secure: true
                      }),
                      width: width
                    };
                  });
                  srcSet = images.map(function (image) {
                    return "".concat(image.url, " ").concat(Math.round(image.width), "w");
                  }).join(",\n");
                  return _context.abrupt("return", srcSet);

                case 6:
                case "end":
                  return _context.stop();
              }
            }
          }, _callee, this);
        }));

        return function (_x) {
          return _ref4.apply(this, arguments);
        };
      }()
    );
  };

  return {
    width: {
      type: _graphql.GraphQLFloat,
      description: 'The original width of the image.'
    },
    height: {
      type: _graphql.GraphQLFloat,
      description: 'The original height of the image.'
    },
    aspectRatio: {
      type: _graphql.GraphQLFloat,
      description: (0, _commonTags.oneLine)(_templateObject())
    },
    base64: {
      type: _graphql.GraphQLString,
      description: (0, _commonTags.oneLine)(_templateObject2()),
      resolve: function () {
        var _resolve = (0, _asyncToGenerator2.default)(
        /*#__PURE__*/
        _regenerator.default.mark(function _callee2(_ref5) {
          var id, path, data;
          return _regenerator.default.wrap(function _callee2$(_context2) {
            while (1) {
              switch (_context2.prev = _context2.next) {
                case 0:
                  id = _ref5.id, path = _ref5.path;
                  _context2.next = 3;
                  return (0, _sharpBase.base64)({
                    file: {
                      id: id,
                      absolutePath: path
                    }
                  });

                case 3:
                  data = _context2.sent;
                  return _context2.abrupt("return", data.src);

                case 5:
                case "end":
                  return _context2.stop();
              }
            }
          }, _callee2, this);
        }));

        return function resolve(_x2) {
          return _resolve.apply(this, arguments);
        };
      }()
    },

    /**
     * Formats.
     *
     * The way this module works these different formats are generated based
     * on the user's query.
     *
     * So if the user does not include srcWebm in their query then a webM version
     * of the asset is not generated.
     *
     * This node will also only upload the image once, then perform the transformations.
     */
    // src
    src: {
      type: _graphql.GraphQLString,
      description: 'Keep original format but optimize quality.',
      resolve: getResolveSrc()
    },
    srcSet: {
      type: _graphql.GraphQLString,
      description: 'Keep original format but optimize quality.',
      resolve: getResolveSrcSet()
    },
    // jpg
    srcJpg: {
      type: _graphql.GraphQLString,
      description: getSrcDescription('JPG'),
      resolve: getResolveSrc('jpg')
    },
    srcSetJpg: {
      type: _graphql.GraphQLString,
      description: getSrcSetDescription('JPG'),
      resolve: getResolveSrcSet('jpg')
    },
    // png
    srcPng: {
      type: _graphql.GraphQLString,
      description: getSrcDescription('PNG'),
      resolve: getResolveSrc('png')
    },
    srcSetPng: {
      type: _graphql.GraphQLString,
      description: getSrcSetDescription('PNG'),
      resolve: getResolveSrcSet('png')
    },
    // webp
    srcWebp: {
      type: _graphql.GraphQLString,
      description: getSrcDescription('Webp'),
      resolve: getResolveSrc('webp')
    },
    srcSetWebp: {
      type: _graphql.GraphQLString,
      description: getSrcSetDescription('Webp'),
      resolve: getResolveSrcSet('webp')
    },
    //----------------------------------------
    // video
    //----------------------------------------
    // jpg
    srcVideoPoster: {
      type: _graphql.GraphQLString,
      description: 'A poster for the video.'
    },
    // mp4
    srcVideoMp4: {
      type: _graphql.GraphQLString,
      description: getSrcDescription('MP4')
    },
    // webm
    srcVideoWebm: {
      type: _graphql.GraphQLString,
      description: getSrcDescription('Webm')
    },
    // ogg
    srcVideoOgg: {
      type: _graphql.GraphQLString,
      description: getSrcDescription('Ogg')
    }
  };
};

exports.commonFields = commonFields;