import { GraphQLObjectType, GraphQLInt, GraphQLFloat } from 'gatsby/graphql'
import { commonFields } from './commonFields'
import { upload } from './cloudinary'

export default ({
    pathPrefix,
    getNodeAndSavePathDependency,
    reporter,
    cloudinary,
}) => {
    return {
        type: new GraphQLObjectType({
            name: 'ImageCloudinaryFixed',
            fields: {
                ...commonFields({ pathPrefix, reporter, cloudinary }),
            },
        }),
        args: {
            width: {
                type: GraphQLInt,
                defaultValue: 400,
            },
            height: {
                type: GraphQLInt,
            },
        },
        resolve: async (image, fieldArgs, context) => {
            /**
             * This function has to provide the public_id
             * of the uploaded image. Then other resolve functions
             * will perform transformations on that public_id.
             *
             * This must also provide:
             * - width
             * - height
             * - aspectRatio
             * - sizes
             *
             * All the transformations will return remote urls on cloudinary.
             */
            const file = getNodeAndSavePathDependency(
                image.parent,
                context.path,
            )
            const id = file.id
            const path = file.absolutePath
            const data = await upload(cloudinary)(id, path)
            const presentationWidth = Math.min(fieldArgs.maxWidth, data.width)
            const sizes = `(max-width: ${presentationWidth}px) 100vw, ${presentationWidth}px`
            return {
                id,
                path,
                width: data.width,
                height: data.height,
                aspectRatio: data.width / data.height,
                maxWidth: fieldArgs.maxWidth,
                maxHeight: fieldArgs.maxHeight,
                sizes,
            }
        },
    }
}
